<!--
  $Source: /doc/html/htdocs/dotfiles/README.md $
  $Host: furbag $
  $UUID: 482f1aca-a064-483e-b971-6d87caece415 $
-->

# My dotfiles

<!--ts-->
   * [Quick start](#quick-start)
   * [Ack](#ack)
   * [Building from a source RPM](#building-from-a-source-rpm)
   * [Changing directories quickly](#changing-directories-quickly)
   * [Command history](#command-history)
   * [Configuration files](#configuration-files)
   * [Crypto: signify](#crypto-signify)
   * [Environment variables](#environment-variables)
   * [GNU info](#gnu-info)
   * [Humor](#humor)
   * [Mail: Mutt](#mail-mutt)
   * [Mail: procmail](#mail-procmail)
   * [Mail: qmail](#mail-qmail)
   * [Mail: Tagged-message delivery agent](#mail-tagged-message-delivery-agent)
   * [Pagers: less and most](#pagers-less-and-most)
   * [Perl](#perl)
   * [PDF viewer](#pdf-viewer)
   * [Recording your terminal session](#recording-your-terminal-session)
   * [Screen and Tmux](#screen-and-tmux)
   * [Shell: Basic setup](#shell-basic-setup)
   * [Shell: Bash](#shell-bash)
   * [Shell: Korn shell](#shell-korn-shell)
   * [Shell: TCSH](#shell-tcsh)
   * [Shell: Zsh](#shell-zsh)
   * [SSH](#ssh)
   * [Template Toolkit](#template-toolkit)
   * [Terminal setup](#terminal-setup)
   * [VCS: Git](#vcs-git)
   * [VCS: Mercurial](#vcs-mercurial)
   * [VIM](#vim)
   * [Web: Creating pages](#web-creating-pages)
   * [Web: Curl](#web-curl)
   * [Web: Firefox](#web-firefox)
   * [Web: Lynx](#web-lynx)
   * [Web: Tidying up pages](#web-tidying-up-pages)
   * [Web: Wget](#web-wget)
   * [Web: W3M](#web-w3m)
   * [X-Windows: setup](#x-windows-setup)
   * [X-Windows: Fluxbox](#x-windows-fluxbox)
   * [X-Windows: FVWM](#x-windows-fvwm)
<!--te-->

## Quick start

So, here are my dotfiles.  I've included some brief descriptions where
appropriate -- most of them have at least a few comments.

You can download the whole thing [here](dotfiles.tgz).

### Ack

Ack is about the neatest thing since sliced bread for grubbing around
in code.  It's fast, portable, ignores VCS directories, and gives good
search results.  Have a look [here](https://beyondgrep.com/why-ack/) for more.

My setup uses basic colors for matching, has decent defaults for directories
(Bazaar, Mercurial) and files to ignore (backups, VI/VIM swap, etc),
and shows how to use defined filetypes.

<pre>
<a href="top/dot-ackrc">+--dot-ackrc</a>
</pre>

### Building from a source RPM

The RPM-macros file holds my settings for building from a source RPM.
A much more thorough one can be found
[here](http://cholla.mmto.org/computers/linux/rpm/dotrpmmacros.html).

<pre>
<a href="top/dot-rpmmacros">+--dot-rpmmacros</a>
</pre>

### Changing directories quickly

I like to minimize keystrokes and typing in general, so when I saw a Stack
Overflow posting about moving between directories with one keystroke,
I jumped all over it.  Unfortunately that posting has disappeared, but
I have functions that will do the trick under Bash and ZSH.

You'll need a program called *grabchars* for this to work.  Grabchars lets
you handle single-character feedback in a portable fashion via command
line or shell-script.  For example, running

    grabchars -c 0123456789 -n2 -t10

interactively reads two numbers with a ten-second timeout, no need to press
return after the numbers.  It's available on Linux boxes, but if you're
running a BSD box and you need to build from source, $DEITY help you.
It's written using sgtty, but the BSDs use termios and moving between them
is a complete goatrope.

<pre>
<a href="top/dot-cdlist">+--dot-cdlist</a>
</pre>

My *.cdlist* file holds 33 directories I use frequently, prefixed with a
number or letter.  I have a shell function **g** which displays that list,
uses grabchars to get your choice, and takes you immediately to that
directory.  Here's the Bash version:

    g () {
        cat $HOME/.cdlist
        local prompt="dir: "
        local ans=$(grabchars -d0 -L -c '[0-9a-zA-Z]' -q"$prompt")
        set X $(grep "^$ans" $HOME/.cdlist)
        case "$#" in
            (3) builtin cd $3 && pwd ;;
            (*) echo no such entry ;;
        esac
    }

Here's the ZSH version, which will look for another *.cdlist* file in
the target directory and run recursively if found:

    unset -f g 2> /dev/null
    g () {
        local dirs=".cdlist"
        local prompt="dir: "
        local olddir=$(pwd)
        cd
        test -f $dirs || { cd $olddir && unset olddir && return }
        clear
        cat $dirs

        local ans=$(grabchars -d- -c '[0-9a-zA-Z]' -q"$prompt")
        case "$ans" in
           q|-) cd $olddir; return ;;
           *) ;;
        esac

        set X $(grep "^${ans} " $dirs)

        case "$#" in
           3) chdir $3 || return ;;
           *) echo "$ans: no such entry"; return ;;
        esac

        if test -f $dirs
        then
            g
        else
            echo; echo; pwd; echo;
            ls --color=always -blptF --time-style='+%d-%b-%Y %T' | head
        fi
    }

### Command history

<pre>
+--<a href="libexec/cmdlog">libexec/cmdlog</a>
+--<a href="cron/newcmdlog">cron/newcmdlog</a>
</pre>

I like keeping my command-line history in a way that doesn't depend on a
particular shell.  I also want to keep history indefinitely *without* ending
up with a single 80-Mb file, especially since ZSH used to have a bad habit
of corrupting the history by randomly adding control characters to entries.

Here's a ZSH function to log commands, return codes and the current
directory.  It uses a hook function called **precmd**, which is executed
before each prompt:

    # Don't try to put local on the x= line.  If you do,
    # any command arguments (i.e., "ls -la") will throw an error:
    #   precmd:local:2: not an identifier: -la
    unset -f precmd 2> /dev/null
    function precmd {
        typeset -i stat=$?
        local _x
        _x=$(fc -ln -1)
        local _d="$(/bin/pwd)"
        $HOME/libexec/cmdlog $$ $stat: $_d: \($_x\)
    }

The function uses a script called **cmdlog** to append the shell PID, last
return code, directory, and command string to the file $HOME/.log/today,
which is hard-linked to $HOME/.log/YYYY/MMDD.  There's not much to it:

    #!/bin/sh
    #< cmdlog: store commands in current logfile.
    exec /bin/echo $(/bin/date "+%T") ${1+"$@"} >> $HOME/.log/today
    exit 1

You can use something like `/usr/bin/logger -p local5.info ${1+"$@"}`
instead if you'd rather.  It's originally based on:

    http://blogs.sun.com/chrisg/entry/logging_commands_in_korn_shell
    Logging commands in korn shell
    Chris Gerhard
    Thu, 2 Mar 2006 09:47:29 -0500

I use a similar setup for bash, which you'll find in the bash rc files.

<pre>
+--dot-log
|   +--2021
|   |   +--<a href="top/dot-log/2021/1106">1106</a>
|   |   +--<a href="top/dot-log/2021/1107">1107</a>
|   +--today        linked to current YYYY/MMDD
</pre>

In ZSH, I occasionally dump a paragraph of text or something equally
useless into the command line without intending to, so this function helps
me clean that up:

    unset -f histedit 2> /dev/null
    histedit () {
        _x="$HOME/.zsh/.histedit"
        fc -ln 1 > $_x && vi $_x && fc -R $_x && rm $_x
    }

### Configuration files

If you want something more standardized for your configuration (i.e.,
other than shotgunning dotfiles all over your home directory), the <a
href="https://wiki.archlinux.org/title/XDG_Base_Directory">XDG</a> setup
is pretty nice.

The <a href="bin/mkxdg">mkxdg</a> script will create a base directory
setup under $HOME if you don't have one already.  Only the top-level
.cache, .config, and .local/{run,share,state} directories are created.
Here's part of mine:

    +--HOME     
    |   +--.cache                   XDG_CACHE_HOME
    |   |   +--borg                   Where user-specific non-essential (cached)
    |   |   |   +--adc0101...         data should go (analogous to /var/cache).
    |   |   +--fontconfig   
    |   |   +--mozilla      
    |   |   |   +--firefox  
    |   |   +--pip          
    |           
    |   +--.config                  XDG_CONFIG_HOME
    |   |   +--borg                   Where user-specific configurations should
    |   |   |   +--security           go (analogous to /etc).
    |   |   |   |   +--adc0101...    
    |   |   +--fontconfig   
    |   |   |   +--conf.d   
    |   |   +--go           
    |   |   +--jenkins      
    |   |   +--neofetch     
    |   |   +--ttree        
    |   |   +--vifm         
    |   |   |   +--colors   
    |   |   |   +--scripts  
    |           
    |   +--.local           
    |   |   +--run                  XDG_RUNTIME_DIR
    |   |   |   +--dconf              Where non-essential user-specific files
    |                                 such as sockets, named pipes, etc. should go
    |                                 (use $HOME/.local/run or /run/user/$UID).
    |           
    |   |   +--share                XDG_DATA_HOME
    |   |   |   +--applications       Where user-specific data files should go
    |   |   |   +--inxi               (analogous to /usr/share).
    |   |   |   +--ranger   
    |   |   |   +--tasks    
    |   |   |   +--vifm     
    |           
    |   |   +--state                XDG_STATE_HOME
    |                                 Where user-specific state files should go
    |                                 (analogous to /var/lib).


### Crypto: signify

This is an OpenBSD program available on FreeBSD through the ports system,
and on Linux via [Github](https://github.com/aperezdc/signify).  The Linux
version is supposed to be portable, but I haven't used it.

<pre>
+--dot-signify
|   +--sign.pub
        untrusted comment: signify public key
        RWS0XADl6wI3WfZv4njFjaz5zsYp+UeSs/VpngekdHX3QX2MKvNoDxLk

|   +--sign.sec
        untrusted comment: signify secret key
        6wkvQVM+/eom+2Ef0080BseZpgwMz+/NkBgdgOrMtzA1IV3FyIRmnz4/Yta9+X5NaZH9IPre
        6v51h5biUj79zkkZHgQloTNnSUl16z0/82bKo1nHKubEQtrSyVNGstyFN1IgTSXjla0=
</pre>

**signify** creates and checks cryptographic signatures, which are used to
verify the integrity of a message.  You can verify entire directory trees,
zip archives, or individual files.  From the manpage:

    Create a new key pair:
       $ signify -G -p newkey.pub -s newkey.sec

    Sign a file, specifying a signature name:
       $ signify -S -s key.sec -m message.txt -x msg.sig

    Verify a signature, using the default signature name:
       $ signify -V -p key.pub -m generalsorders.txt

### Environment variables

You're missing out if you've never used any of Dan Bernstein's software.
If nothing else, you'll get a whole new respect for how helpful the
filesystem can be if you don't go out of your way to fight with it.

One of his programs (*envdir*) reads a directory holding one file per
environment variable to set.  The filename is the variable name, and the
contents are how the variable is set.  I've found this useful on several
occasions where I had to start several programs with LOTS of environment
variables but only one or two differences -- make several directories,
hard-link the matching variables and edit the rest.

<pre>
+--dot-env
|   +--<a href="top/dot-env/BLOCKSIZE">BLOCKSIZE</a>
|   +--<a href="top/dot-env/DOCROOT">DOCROOT</a>
|   +--<a href="top/dot-env/DOMAIN">DOMAIN</a>
|   +--<a href="top/dot-env/EDITOR">EDITOR</a>
|   +--<a href="top/dot-env/PAGER">PAGER</a>
|   +--<a href="top/dot-env/PATH">PATH</a>
|   +--<a href="top/dot-env/SHELL">SHELL</a>
|   +--<a href="top/dot-env/TERM">TERM</a>
|   +--<a href="top/dot-env/TERMINFO">TERMINFO</a>
</pre>

This is my attempt to make a generic environment variable setup that's usable
across different operating systems.

* "dot-envrc" holds simple settings in a shell-agnostic format.
* a program called "buildenv" writes C-shell and Bourne-shell versions
of "dot-envrc" that you can source from whatever you run.

<pre>
+--<a href="top/dot-envrc">dot-envrc</a>
+--<a href="top/dot-envrc.csh">dot-envrc.csh</a>
+--<a href="top/dot-envrc.sh">dot-envrc.sh</a>

+--<a href="bin/buildenv">buildenv</a>
</pre>

The files below do things the Bernstein way -- line 1 holds the environment
variable I'm trying to set, line 2 is empty, and everything else holds
optional descriptions or comments.

<pre>
+--<a href="top/dot-javapath">dot-javapath</a>
+--<a href="top/dot-manpath">dot-manpath</a>
+--<a href="top/dot-path">dot-path</a>
</pre>

This setup is very flexible:

<pre>
setenv () { export $1="$2"; }

test -f ~/.path     && eval setenv $(head -1 ~/.path)
test -f ~/.javapath && eval setenv $(head -1 ~/.javapath)
test -f ~/.manpath  && eval setenv $(head -1 ~/.manpath)
test -f ~/.envrc.sh && source ~/.envrc.sh
</pre>

Configuration file for dircolors, a utility to help you set the
LS_COLORS environment variable used by GNU ls with the --color option.

<pre>
+--<a href="top/dot-dircolors">dot-dircolors</a>
+--<a href="top/dot-dircolors.sh">dot-dircolors.sh</a>
</pre>

### GNU info

Makes "info" a bit more usable by *not* having the viewer automatically
jump between chapters.

<pre>
+--<a href="top/dot-infokey">dot-infokey</a>
</pre>

### Humor

Stupid quotes I've been collecting since the early '90s.  These are rude,
tasteless, and guaranteed to offend.

<pre>
+--<a href="top/dot-quotes">dot-quotes</a>
</pre>

### Mail: Mutt

If you get a ton of mail and you want a quick, efficient client to handle
it, you can't do much better than Mutt.

<pre>
+--<a href="top/dot-muttrc">dot-muttrc</a>
+--<a href="top/dot-muttrc.maildir">dot-muttrc.maildir</a>
+--dot-mutt
|  +--<a href="top/dot-mutt/SETUP">SETUP</a>
|  +--<a href="top/dot-mutt/auto_views">auto_views</a>
|  +--<a href="top/dot-mutt/bindings">bindings</a>
|  +--<a href="top/dot-mutt/fcc-hooks">fcc-hooks</a>
|  +--<a href="top/dot-mutt/folder-hooks">folder-hooks</a>
|  +--<a href="top/dot-mutt/headers">headers</a>
|  +--<a href="top/dot-mutt/macros">macros</a>
|  +--<a href="top/dot-mutt/mailboxes">mailboxes</a>
|  +--<a href="top/dot-mutt/message-hooks">message-hooks</a>
|  +--<a href="top/dot-mutt/muttrc-original">muttrc-original</a>
|  +--<a href="top/dot-mutt/non-standard">non-standard</a>
|  +--<a href="top/dot-mutt/save-hooks">save-hooks</a>
|  +--<a href="top/dot-mutt/signature">signature</a>
</pre>

One of the things I like best is the ability to use external programs in
your settings.  In my .muttrc file:

    # Generate a signature with a quote.
    set signature="makesig|"        # file which contains my signature

    # Convert date to local timezone.
    set display_filter="~/libexec/display-local-date"

**makesig** prints a generic signature and then adds a random quote.
Here's **display-local-date**:

    #!/bin/sh
    #<display-local-date: display date in my timezone.

    export PATH=/usr/local/bin:/bin:/usr/bin
    tmp=/tmp/dsp.$$.$RANDOM          # mktemp is overkill here.

    cat - > $tmp                     # save the message,
    DATE=$(formail -xDate: < $tmp)   # extract and convert the date,
    DATE=$(date -R -d "$DATE")
    echo "Date: $DATE"               # and output the modified message
    formail -fI Date < $tmp
    rm -f $tmp
    exit 0

These are a few color-schemes I've tried.  I settled on "xterm-prod"
because my eyesight sucks and this one was the least distracting.

<pre>
|  +--<a href="top/dot-mutt/colours">colours</a>
|  +--<a href="top/dot-mutt/colours-modified-dark">colours-modified-dark</a>
|  +--<a href="top/dot-mutt/colours-order">colours-order</a>
|  +--<a href="top/dot-mutt/colours-production">colours-production</a>
|  +--<a href="top/dot-mutt/colours-randy">colours-randy</a>
|  +--<a href="top/dot-mutt/colours-reverse-bw">colours-reverse-bw</a>
|  +--<a href="top/dot-mutt/colours-stackoverflow">colours-stackoverflow</a>
|  +--<a href="top/dot-mutt/colours-test">colours-test</a>
|  +--<a href="top/dot-mutt/colours-ucla">colours-ucla</a>
|  +--<a href="top/dot-mutt/colours-xterm-prod">colours-xterm-prod</a>
</pre>

**Solarized** is a 16-color palette (8 monotones, 8 accent colors) designed
for use with terminal and GUI applications.  It has a few nice properties:

- Reduces brightness contrast but, unlike many low contrast colorschemes,
retains contrasting hues for syntax highlighting readability.

- Switching from dark to light mode retains the same perceived contrast
in brightness between each value.  Each mode is equally readable.

<pre>
|  +--solarized
|  |  +--<a href="top/dot-mutt/solarized/README.md">README.md</a>
|  |  +--<a href="top/dot-mutt/solarized/3b23c55-dark-16">3b23c55-dark-16</a>
|  |  +--<a href="top/dot-mutt/solarized/3b23c55-dark-256">3b23c55-dark-256</a>
|  |  +--<a href="top/dot-mutt/solarized/3b23c55-light-16">3b23c55-light-16</a>
|  |  +--<a href="top/dot-mutt/solarized/3b23c55-light-256">3b23c55-light-256</a>
|  |  +--<a href="top/dot-mutt/solarized/3b23c55-template">3b23c55-template</a>
|  |  +--<a href="top/dot-mutt/solarized/mutt-compile-colors.sh">mutt-compile-colors.sh</a>
</pre>

### Mail: procmail

The Swiss-Army-chainsaw for email.  I like being able to

- save a copy of just the header for incoming messages,
- allow posting to my blog via email by writing 4 lines of code, and
- check for (and discard) duplicate messages using the message-id.

<pre>
+--<a href="top/dot-procmailrc">dot-procmailrc</a>
</pre>

### Mail: qmail

More Bernstein software.  It's crazy flexible -- creating one file like
**.qmail-bcc** allows me to include "vogelke-bcc" in an outgoing message
and have a copy blind-courtesied to me.  It's way better than relying on
your MUA because the mail actually goes through the same delivery process
as any other outgoing mail, so you can see what headers were generated in
a failed message.

<pre>
+--<a href="top/dot-qmail">dot-qmail</a>
+--<a href="top/dot-qmail-bcc">dot-qmail-bcc</a>
+--<a href="top/dot-qmail-blog">dot-qmail-blog</a>
+--<a href="top/dot-qmail-default">dot-qmail-default</a>
+--<a href="top/dot-qmail-header">dot-qmail-header</a>
+--<a href="top/dot-qmail-maildir">dot-qmail-maildir</a>
+--<a href="top/dot-qmail-xnote">dot-qmail-xnote</a>
</pre>

### Mail: Tagged-message delivery agent

TMDA is a vastly underrated way to create unlimited disposable email
addresses that can be associated with a given user or have a time-limit
imposed.  You can give one of these to an untrusted party with (say) a
1-day time limit, and anyone who tries to use that address after a day
will simply never get through.

<pre>
+--dot-tmda
|   +--<a href="top/dot-tmda/config">config</a>
|   +--<a href="top/dot-tmda/crypt_key">crypt_key</a>
</pre>

### Pagers: less and most

You can do all sorts of neat things with **less**, including keyboard
shortcuts and extensive customization using the environment.

**most** is another file browser which is nice for files containing very
long lines.

<pre>
+--<a href="top/dot-lessenv">dot-lessenv</a>
+--<a href="top/dot-lesskey">dot-lesskey</a>
+--<a href="top/dot-mostrc">dot-mostrc</a>
</pre>

### Perl

It's old but it does the trick, and it's still under active development.
**perlcritic** will read your code and try to identify awkward, hard to read,
error-prone, or unconventional constructs.  Most of the rules are based on
Damian Conway's book Perl Best Practices.  However, **perlcritic** is not
limited to enforcing PBP, and it will even support rules that contradict
Conway.  All rules can easily be configured or disabled to your liking.

**perltidy** reads a perl script and writes an indented, reformatted script.
It does for perl what **tidy** does for HTML.

<pre>
+--<a href="top/dot-perlcriticrc">dot-perlcriticrc</a>
+--<a href="top/dot-perltidyrc">dot-perltidyrc</a>
</pre>

### PDF viewer

<pre>
+--<a href="top/dot-xpdfrc">dot-xpdfrc</a>
</pre>

### Recording your terminal session

I use a small wrapper around *tmux* to automatically save output from
a shell session:

    #!/bin/bash
    #<saveon: use tmux as better script -- automatic save on exit.

    export PATH=/usr/local/bin:/bin:/usr/bin
    tag=${0##*/}
    umask 022

    # Runtime info.
    osname () { me=$(uname -n); os=$(uname -srm); echo "$me $os"; }
    when ()   { date '+%a, %d %b %Y %T %z'; }

    # Setup and sanity checks.
    out='typescript'
    work='typescript.n'

    printf "Running on: %s\n%s\n" "$(osname)" "$(when)" > $out
    tmux

    sedscr='
      /^Pane is dead/d
      /^me%$/d
      /^root#$/d
      s/^me%/\nme%/g
      s/^root#/\nroot#/g
      s/  *$//g
    '

    { sed -e "$sedscr" $work | cat -s; when; }  >> $out
    rm $work
    exit 0

My $HOME/.tmux.conf file -- fix default-shell to suit yourself:

    #.tmux.conf: setup for saving output like "script"

    # scrollback size
    set -g history-limit 500000

    # shell -- season to taste
    set -g default-shell /bin/ksh

    # change ctrl-b to ctrl-a as the command button
    unbind C-b
    set -g prefix C-a

    # Sat, 22 Jan 2022 00:04:11 -0500
    # https://unix.stackexchange.com/questions/26548
    # When I exit my running shell, pane output is saved to file "typescript".
    # -JC keeps trailing spaces and joins lines that have been split; kill
    # the trailing spaces later.

    set -g remain-on-exit
    set-hook -g pane-died 'capture-pane -JC -S - -E - ;\
        save-buffer typescript.n ;\
        delete-buffer;\
        kill-pane;\
        kill-window;'

A session looks like this:

    zsh% saveon
    [screen clears]

    me% pwd
    /home/vogelke/notebook/2022/0628

    me% ls -l r*
    -rw-r--r-- 1 vogelke mis  2064 28-Jun-2022 03:21:00 reddit-bash-truss
    -rw-r--r-- 1 vogelke mis  3217 28-Jun-2022 22:18:05 reddit-tmux-script
    -rw-r--r-- 1 vogelke mis 25305 28-Jun-2022 08:05:11 risks.xml

    me% exit
    [exited]

    zsh%

Results:

    % cat -n typescript 
     1  Running on: furbag FreeBSD 11.3-RELEASE amd64
     2  Tue, 28 Jun 2022 22:22:28 -0400
     3
     4  me% pwd
     5  /home/vogelke/notebook/2022/0628
     6
     7  me% ls -l r*
     8  -rw-r--r-- 1 vogelke mis  2064 28-Jun-2022 03:21:00 reddit-bash-truss
     9  -rw-r--r-- 1 vogelke mis  3217 28-Jun-2022 22:18:05 reddit-tmux-script
    10  -rw-r--r-- 1 vogelke mis 25305 28-Jun-2022 08:05:11 risks.xml
    11
    12  me% exit
    13
    14  Tue, 28 Jun 2022 22:22:47 -0400

Advantages:

* I don't have to do anything to save the results -- exiting tmux does
that for me.

* I get a one-line header showing what system I was on plus date-stamps
when I enter and leave the session, without tons of empty lines or stupid
carriage-returns.

* This may be a bug or a feature -- I have to remember to rename typescript,
or it gets overwritten on the next run.

### Screen and Tmux

My defaults:

<pre>
+--<a href="top/dot-screenrc">dot-screenrc</a>
+--<a href="top/dot-tmux.conf">dot-tmux.conf</a>
</pre>

**screen** can do some interesting things.  I've found that programs like
**ncdu** which can use a nice colorscheme will sometimes run better under
screen.

I like to cache the information used by **ncdu** for large directories
that take time to display.  Here's an example using my $HOME directory
and the cache file *.ncdu*:

    me% pwd
    /home/vogelke

    me% /usr/local/bin/ncdu -1xo- > .ncdu
    /home/vogelke/OLD/...edhf6.default/3D4E0d01   817299 files

This is where things get interesting.  I run **ncdu** under screen, but I
need to change the arguments depending on whether a cache file exists.  The
(somewhat ugly) way to do this was to use a driver script **$HOME/bin/ncdu**
to set an environment variable with the arguments:

    #!/bin/ksh
    #<ncdu: run DU browser with a cached file if it exists.
    #       Assumes ".ncdu" holds cached DU information.

    export PATH=/usr/local/bin:/bin:/usr/bin
    set -o nounset
    tag=${0##*/}
    umask 022

    # Check current directory for cache file.
    export NCARGS=
    test -f ".ncdu" && NCARGS="-f .ncdu"

    # Use special setup file which uses "stuff" plus the NCARGS variable to 
    # invoke ncdu with the right cache file.
    screen -c ~/.screenrc.ncdu
    exit 0

**screen** can read environment variables, so the dotfile does the rest.
The line starting with "stuff" will put "ncdu" followed by "exit" into
the command buffer as if you'd typed it:

<pre>
+--<a href="top/dot-screenrc.ncdu">dot-screenrc.ncdu</a>
</pre>

### Shell: Basic setup

<pre>
+--<a href="top/dot-profile">dot-profile</a>
+--<a href="top/dot-shrc">dot-shrc</a>
</pre>

*.profile* sets up PAGER and prompt preferences.

Here are the files opened by /bin/sh (FreeBSD) for interactive mode, other
than libraries:

    $HOME/.termcap.db
    $HOME/.termcap
    /usr/share/misc/termcap.db
    $HOME/.editrc
    $HOME/.shrc       (only if environment variable ENV is set to $HOME/.shrc)

### Shell: Bash

<pre>
+--<a href="libexec/bashlog">libexec/bashlog</a>
+--<a href="top/dot-bashalias">dot-bashalias</a>
+--<a href="top/dot-bashrc">dot-bashrc</a>
+--<a href="top/dot-bash_dircolors">dot-bash_dircolors</a>
+--<a href="top/dot-bash_login">dot-bash_login</a>
+--<a href="top/dot-bash_logout">dot-bash_logout</a>
+--<a href="top/dot-bash_profile">dot-bash_profile</a>
</pre>

Here are the files opened by statically-linked bash 5.2.15(1)-release
(FreeBSD) in order for interactive mode:

    /etc/nsswitch.conf
    /etc/pwd.db
    $HOME/.termcap.db
    $HOME/.termcap
    /usr/share/misc/termcap.db
    $HOME/.bashrc
    /etc/localtime
    /usr/share/zoneinfo/posixrules
    $HOME/.inputrc
    /etc/inputrc
    $HOME/.bash_history

I use code in *.bashrc* based on
[this](https://jichu4n.com/posts/debug-trap-and-prompt_command-in-bash/)
to log all commands in a separate file.

### Shell: Korn shell

<pre>
+--<a href="top/dot-kshrc">dot-kshrc</a>
</pre>

This checks for a file called ".env" and sources it when entering or leaving
a directory.  Saves a lot of time if you often switch between projects.
Here are the files opened by ksh (FreeBSD ksh93-20120801_2) in order for
interactive mode:

    .kshrc
    .paths       (searched for in all PATH directories, looking for plugins)
    /etc/ksh_audit

### Shell: TCSH

<pre>
+--<a href="top/dot-cshrc">dot-cshrc</a>
+--<a href="top/dot-tcshrc">dot-tcshrc</a>
+--<a href="top/dot-login">dot-login</a>
+--<a href="top/dot-logout">dot-logout</a>
</pre>

This was my favorite shell before discovering Zsh.  Here are the files
opened by tcsh 6.20.00 2016-11-24 (x86_64-amd-FreeBSD) in order for
interactive mode:

    /etc/nsswitch.conf
    /etc/pwd.db
    /etc/group
    /etc/csh.cshrc
    $HOME/.tcshrc
    $HOME/.termcap.db
    $HOME/.termcap
    /usr/share/misc/termcap.db
    $HOME/.history
    /etc/localtime
    /usr/share/zoneinfo/posixrules

### Shell: Zsh

There are way too many cool things about Zsh to include here.

The completion stuff is great, easily the equal of bash or tcsh.  If you
want to complete (say) hostnames for commands like "ping", "host" etc.,
you can create a file holding hostnames and set up completion like so:

    ZCACHEDIR="$HOME/.zsh/cache"

    zstyle ':completion:*' cache-path $ZCACHEDIR
    zstyle ':completion:*' use-cache on
    compinit -C -d $ZCACHEDIR/compdump

    # Hostname completion
    test -f "$ZCACHEDIR/hosts" &&
        hosts=(`cat $ZCACHEDIR/hosts`) &&
        zstyle '*' hosts $hosts &&
        unset hosts

This is included in the completion.zsh file; even with nearly 3000 hosts
in the cache file, partial or full completion happens with almost no delay.

<pre>
+--<a href="top/dot-zshrc">dot-zshrc</a>
+--<a href="top/dot-zlogin">dot-zlogin</a>
+--<a href="top/dot-zcompdump">dot-zcompdump</a>

+--dot-zsh
|  +--<a href="top/dot-zsh/aliases.zsh">aliases.zsh</a>
|  +--<a href="top/dot-zsh/bindkeys.zsh">bindkeys.zsh</a>
|  +--cache
|  |  +--<a href="top/dot-zsh/cache/RPMs">RPMs</a>
|  |  +--<a href="top/dot-zsh/cache/compdump">compdump</a>
|  |  +--<a href="top/dot-zsh/cache/perl_modules">perl_modules</a>
|  |  +--<a href="top/dot-zsh/cache/python_modules">python_modules</a>
|  +--<a href="top/dot-zsh/colors.zsh">colors.zsh</a>
|  +--<a href="top/dot-zsh/completion.zsh">completion.zsh</a>
|  +--<a href="top/dot-zsh/exports.zsh">exports.zsh</a>
|  +--<a href="top/dot-zsh/functions.zsh">functions.zsh</a>
|  +--<a href="top/dot-zsh/hg-completion">hg-completion</a>
|  +--<a href="top/dot-zsh/history.zsh">history.zsh</a>
|  +--<a href="top/dot-zsh/hooks.zsh">hooks.zsh</a>
|  +--<a href="top/dot-zsh/init.zsh">init.zsh</a>
|  +--<a href="top/dot-zsh/prompt.zsh">prompt.zsh</a>
|  +--<a href="top/dot-zsh/setopt.zsh">setopt.zsh</a>
</pre>

### SSH

I've included the parts of my server and client configuration files that you
can use to make a host STIG-compliant (MAC-2 Sensitive).  tl;dr -- you need
more for Top-Seekie-No-Peekie stuff, but it's fine for most other things.

The **newkey** script will create new keys for connecting to a given host.
I like having a unique keypair for every host I use.

<pre>
+--dot-ssh
|   +--<a href="top/dot-ssh/newkey">newkey</a>
|   +--<a href="top/dot-ssh/ssh_config">ssh_config</a>
|   +--<a href="top/dot-ssh/sshd_config">sshd_config</a>
</pre>

### Template Toolkit

My preference any time I need to create a template.  See the
Template::Tutorial::Web manpage for a nice intro.

<pre>
+--<a href="top/dot-tpagerc">dot-tpagerc</a>
+--<a href="top/dot-ttreerc">dot-ttreerc</a>
+--dot-config
|   +--ttree
|   |   +--<a href="top/dot-config/ttree/sunpage">sunpage</a>
</pre>

### Terminal setup

I use these depending on what terminal emulator I run.

<pre>
+--<a href="top/dot-termrc.gnome-term">dot-termrc.gnome-term</a>
+--<a href="top/dot-termrc.xterm">dot-termrc.xterm</a>
</pre>

This section is very helpful if **less** doesn't behave when displaying colors:

    export LESS_TERMCAP_mb=$'\E[01;31m'
    export LESS_TERMCAP_md=$'\E[01;31m'
    export LESS_TERMCAP_me=$'\E[0m'
    export LESS_TERMCAP_se=$'\E[0m'
    export LESS_TERMCAP_so=$'\E[01;47;34m'
    export LESS_TERMCAP_ue=$'\E[0m'
    export LESS_TERMCAP_us=$'\E[01;32m'

### VCS: Git

The cat's meow when it comes to a distributed version control system.
I can use it, but I prefer Mercurial -- it seems a bit simpler.

<pre>
+--<a href="top/dot-gitattributes">dot-gitattributes</a>
+--<a href="top/dot-gitconfig">dot-gitconfig</a>
+--<a href="top/dot-gitignore">dot-gitignore</a>
</pre>

### VCS: Mercurial

I like the basic default workflow plus keyword-handling.

<pre>
+--dot-hg
|   +--<a href="top/dot-hg/multiline">multiline</a>
|   +--<a href="top/dot-hg/style">style</a>
+--<a href="top/dot-hgignore">dot-hgignore</a>
+--<a href="top/dot-hgrc">dot-hgrc</a>
</pre>

If you want to see a ridiculous misuse of software, I use RCS to generate
release version tags for Mercurial.  The script is called **reltag**:

    > reltag
    0.0
    > reltag -i
    1.0
    > reltag -i
    1.1
    > reltag -n
    2.1
    > reltag -i
    2.2
    > reltag
    2.2
    > reltag -i
    2.3
    > reltag -c
    21:49:41 reltag: Cleaning out all version files
    > reltag
    0.0

All it does is create a junk file, check it in when appropriate,
and read the resulting version number.  There's no reason for me to write code
to do that when RCS handles it so nicely.

You can find the script [here](bin/reltag).

### VIM

My preference since last century.

<pre>
+--<a href="top/dot-vimrc">dot-vimrc</a>
+--<a href="top/dot-vimrc-green">dot-vimrc-green</a>
+--<a href="top/dot-vimrc-mutt">dot-vimrc-mutt</a>
+--<a href="top/dot-vimrc-prod">dot-vimrc-prod</a>
+--<a href="top/dot-vimrc-share">dot-vimrc-share</a>
+--<a href="top/dot-vimrc-simple">dot-vimrc-simple</a>

+--dot-vim
|  +--<a href="top/dot-vim/colorsample.vim">colorsample.vim</a>
|  +--<a href="top/dot-vim/filetype.vim">filetype.vim</a>
|  +--<a href="top/dot-vim/newvim">newvim</a>
|  +--ftplugin
|  |  +--<a href="top/dot-vim/ftplugin/c.vim">c.vim</a>
|  |  +--<a href="top/dot-vim/ftplugin/perl.vim">perl.vim</a>
|  |  +--<a href="top/dot-vim/ftplugin/txt.vim">txt.vim</a>
|  +--plugin
|  |  +--<a href="top/dot-vim/plugin/justify.vim">justify.vim</a>
|  |  +--<a href="top/dot-vim/plugin/obviousmode.vim">obviousmode.vim</a>
|  |  +--<a href="top/dot-vim/plugin/setcolors.vim">setcolors.vim</a>
|  |  +--<a href="top/dot-vim/plugin/templates.vim">templates.vim</a>
|  +--syntax
|  |  +--<a href="top/dot-vim/syntax/crontab.vim">crontab.vim</a>
|  |  +--<a href="top/dot-vim/syntax/perl.vim">perl.vim</a>
|  |  +--<a href="top/dot-vim/syntax/sh.vim">sh.vim</a>
|  |  +--<a href="top/dot-vim/syntax/syncolor.vim">syncolor.vim</a>
|  |  +--<a href="top/dot-vim/syntax/syntax.vim">syntax.vim</a>
|  |  +--<a href="top/dot-vim/syntax/txt2tags.vim">txt2tags.vim</a>
|  +--<a href="top/dot-vim/undodir">undodir</a>
|  +--<a href="top/dot-vim/view">view</a>
|  +--<a href="top/dot-vim/xterm256-colors.vim">xterm256-colors.vim</a>
</pre>

The thing I probably like most about VIM is being able to use templates
when I create a new file:

<pre>
+--dot-vim
|  +--dynamic
|  |  +--<a href="top/dot-vim/dynamic/css">css</a>
|  |  +--<a href="top/dot-vim/dynamic/htm">htm</a>
|  |  +--<a href="top/dot-vim/dynamic/md">md</a>
|  |  +--<a href="top/dot-vim/dynamic/pl">pl</a>
|  |  +--<a href="top/dot-vim/dynamic/sh">sh</a>
|  |  +--<a href="top/dot-vim/dynamic/txt">txt</a>
</pre>

The code is in *.vimrc* under the *Dynamic templates* section.

These files use a basic shell to read a template and generate a new file:

    me% cat ~/.vim/dynamic/htm
    cat <<- EndTemplate
    <!DOCTYPE html>
    <!-- @FILENAME@ -->
    <html>
    <head>
      <title>@FILENAME@</title>
      <link rel="stylesheet" type="text/css" href="style.css" />
      <style type="text/css">
      /* <![CDATA[ */
        *    { padding: 0; }
        body { background: white; color: black; margin: 0 10% 10% 0; }
      /* ]]> */
      </style>
    </head>

    <body>
      <h1>H1 header</h1>
    </body>
    </html>
    EndTemplate

When I run *vim newfile.htm*, I get a basic HTML file:

    <!DOCTYPE html>
    <!-- newfile -->
    <html>
    <head>
      <title>newfile</title>
      ...

The VIM colorschemes I've tried can be found under $HOME/.vim/colors:

<pre>
+--dot-vim
|  +--colors
|  |  +--<a href="top/dot-vim/colors/bernhard.vim">bernhard.vim</a>
|  |  +--<a href="top/dot-vim/colors/molokai.vim">molokai.vim</a>
|  |  +--<a href="top/dot-vim/colors/muratori.vim">muratori.vim</a>
|  |  +--<a href="top/dot-vim/colors/murphy.vim">murphy.vim</a>
|  |  +--<a href="top/dot-vim/colors/nofrils-acme.vim">nofrils-acme.vim</a>
|  |  +--<a href="top/dot-vim/colors/nofrils-blue.vim">nofrils-blue.vim</a>
|  |  +--<a href="top/dot-vim/colors/nofrils-dark.vim">nofrils-dark.vim</a>
|  |  +--<a href="top/dot-vim/colors/nofrils-green.vim">nofrils-green.vim</a>
|  |  +--<a href="top/dot-vim/colors/nofrils-light.vim">nofrils-light.vim</a>
|  |  +--<a href="top/dot-vim/colors/nofrils-sepia.vim">nofrils-sepia.vim</a>
|  |  +--<a href="top/dot-vim/colors/shirotelin.vim">shirotelin.vim</a>
|  |  +--<a href="top/dot-vim/colors/vadelma.vim">vadelma.vim</a>
|  |  +--<a href="top/dot-vim/colors/wikipedia.vim">wikipedia.vim</a>
</pre>

You can find [screenshots here](top/vim-colorschemes).

### Web: Creating pages

If you can tolerate perl (I love it), the HTML::TextToHTML module includes
a script for converting text to HTML.

If you like writing articles or tutorials, [txt2tags](http://txt2tags.org)
has some nice templates.

<pre>
+--<a href="top/dot-txt2html.dict">dot-txt2html.dict</a>
+--<a href="top/dot-txt2htmlrc">dot-txt2htmlrc</a>
+--<a href="top/dot-txt2tagsrc">dot-txt2tagsrc</a>
</pre>

### Web: Curl

The only things I generally tweak are where to find certs and what to use
for the User-Agent header; some sites are a PITA about that.

<pre>
+--<a href="top/dot-curlrc">dot-curlrc</a>
</pre>

### Web: Firefox

If you like tweaking your browser appearance.

<pre>
+--dot-mozilla
|   +--<a href="top/dot-mozilla/userChrome.css">userChrome.css</a>
</pre>

### Web: Lynx

I keep the defaults (mostly) -- it's useful to save persistent cookies
and automatically accept those from sites you trust without being prompted.

<pre>
+--<a href="top/dot-lynx.lss">dot-lynx.lss</a>
+--<a href="top/dot-lynxcfg">dot-lynxcfg</a>
</pre>

### Web: Tidying up pages

If you want to check, correct, or pretty-print HTML files, you can't do
better than [tidy](https://github.com/htacg/tidy-html5).  It's great if you
need to write standards-compliant HTML.

The only problem I've found so far concerns grids.  Versions 5.4.0 and 5.9.20
don't recognize the \<grid\> tag, and they botch \<div\> tags within grids.
Putting \<grid\> in .tidyrc as a new block-level tag didn't help.

<pre>
+--<a href="top/dot-tidyrc">dot-tidyrc</a>
+--<a href="top/dot-tidyxmlrc">dot-tidyxmlrc</a>
</pre>

### Web: Wget

If you don't have curl.

<pre>
+--<a href="top/dot-wgetrc">dot-wgetrc</a>
</pre>

### Web: W3M

Great for rendering tables in monospace plain-text.

<pre>
+--dot-w3m
|   +--<a href="top/dot-w3m/config">config</a>
</pre>

### X-Windows: setup

I don't boot into X; I'd much rather start a regular console session and
then run **xinit** when I'm ready.

I've tried several terminal emulators, but when it comes to memory size,
responsiveness, and functionality, I always end up going back to **xterm**.
My .Xdefaults file has lots of stuff taken from the xterm maintainer's site.

<pre>
+--<a href="top/dot-Xdefaults">dot-Xdefaults</a>
+--<a href="top/dot-Xdefaults.urxvt">dot-Xdefaults.urxvt</a>
+--<a href="top/dot-Xdefaults.xalarm">dot-Xdefaults.xalarm</a>

+--<a href="top/dot-xinitrc">dot-xinitrc</a>         --linked to xinitrc-fluxbox
+--<a href="top/dot-xinitrc-fluxbox">dot-xinitrc-fluxbox</a>
+--<a href="top/dot-xinitrc-fvwm2">dot-xinitrc-fvwm2</a>
+--<a href="top/dot-xinitrc-kde">dot-xinitrc-kde</a>
+--<a href="top/dot-xinitrc-metacity">dot-xinitrc-metacity</a>

+--<a href="top/dot-xmodmap">dot-xmodmap</a>
+--<a href="top/dot-xmodmap.swapcaps">dot-xmodmap.swapcaps</a>
</pre>

If you have the Xft libraries installed, you can exercise fine control over
fonts.  Here's how I start one of two Xterm sessions at login:

    /usr/local/bin/xterm -geometry 80x40-0+0 -j -b 10 -sb -si \
        -sk -ls -cr blue -sl 4000 -bd black -bg #ffffff -u8   \
        -fa xft:Cascadia:pixelsize=20:bold -title Remote

### X-Windows: Fluxbox

This is the easiest window-manager I've ever used.  I was able to build
from source in about 20 minutes, and it took maybe another 30 to get it
set up exactly the way I wanted:

* Desktop 1 with two XTerm sessions
* Desktop 2 with Firefox taking up the whole screen
* Two more desktops in reserve for things like PDF viewing, etc.
* F1-F4 move immediately to Desktop 1-4, respectively
* F5 locks the screen
* F10 takes a screenshot
* F11 toggles fullscreen on or off in XTerms
* F12 flips between XTerms; focus-follows-mouse works
* PageUp/Down scrolls XTerms and Firefox sensibly
* Arrow keys work sensibly in VIM and my shell

<pre>
<a href="top/dot-xinitrc-fluxbox">dot-xinitrc-fluxbox</a>

+--dot-fluxbox
|  +--<a href="top/dot-fluxbox/apps">apps</a>
|  +--<a href="top/dot-fluxbox/init">init</a>
|  +--<a href="top/dot-fluxbox/keys">keys</a>
|  +--<a href="top/dot-fluxbox/lastwallpaper">lastwallpaper</a>
|  +--<a href="top/dot-fluxbox/log">log</a>
|  +--<a href="top/dot-fluxbox/menu">menu</a>
|  +--<a href="top/dot-fluxbox/overlay">overlay</a>
|  +--<a href="top/dot-fluxbox/startup">startup</a>
|  +--styles
|  |  +--<a href="top/dot-fluxbox/styles/LemonSpace">LemonSpace</a>
|  |  +--<a href="top/dot-fluxbox/styles/Meta">Meta</a>
|  +--<a href="top/dot-fluxbox/windowmenu">windowmenu</a>
</pre>

### X-Windows: FVWM

If you're REALLY old-school, knock yourself out.

<pre>
<a href="top/dot-xinitrc-fvwm2">dot-xinitrc-fvwm2</a>

+--dot-fvwm
|   +--<a href="top/dot-fvwm/config">config</a>
|   +--fvwm_icons
|   |   +--<a href="top/dot-fvwm/fvwm_icons/arrdown2.xpm">arrdown2.xpm</a>
|   |   +--<a href="top/dot-fvwm/fvwm_icons/arrows2.xpm">arrows2.xpm</a>
|   |   +--<a href="top/dot-fvwm/fvwm_icons/arrup2.xpm">arrup2.xpm</a>
|   |   +--<a href="top/dot-fvwm/fvwm_icons/xterm.xpm">xterm.xpm</a>
|   |   +--<a href="top/dot-fvwm/fvwm_icons/xv.xpm">xv.xpm</a>
|   |   +--<a href="top/dot-fvwm/fvwm_icons/xv2.xpm">xv2.xpm</a>
|   |   +--<a href="top/dot-fvwm/fvwm_icons/xview.xpm">xview.xpm</a>
|   +--<a href="top/dot-fvwm/SETUP">SETUP</a>
</pre>

That's all, folks.

  <hr>
  <table>
    <tr>
      <td class="ftleft"><em>
          $Revision: 28a83bd0b113 $
      </em></td>
      <td class="ftright"><em>
          $Date: Thu, 08 Aug 2024 16:18:15 -0400 $
      </em></td>
    </tr>
  </table>
</body>
</html>
